==> jc-1.4.0.tar.gz: soot/shimple/toolkits/scalar/SEvaluator__24MetaConstant.h <==
// public abstract class soot.shimple.toolkits.scalar.SEvaluator$MetaConstant

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a4a584ce60f6ce4 soot_jimple_Constant
// @dep_class 430b138846f45212 soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant

// header file dependencies
// @dep_header soot_jimple_Constant

#include "soot/jimple/Constant.h"

#ifndef _JC_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant_H_
#define _JC_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_refs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_refs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_nonrefs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$refs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$refs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$nonrefs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$object	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$object;

typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vmethods	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vmethods;
typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vtable	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vtable;
typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vtype	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vtype;

// Constructors
extern void _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$object *);

// Virtual methods structure
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vmethods {
};

// Vtable
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_Constant$vmethods	soot_jimple_Constant;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vmethods	soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant;
};

// Vtype
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vtype {
	_jc_type			type;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$refs {
    _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_refs	soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant;
    _jc_soot_jimple_Constant$sub_refs	soot_jimple_Constant;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_Constant$sub_nonrefs	soot_jimple_Constant;
    _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_nonrefs	soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant;
};

// Object instance structure
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$object {
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vtype	*vtype;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vtype _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$class_object;

#endif	/* _JC_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant_H_ */

==> jc-1.4.6.tar.gz: soot/shimple/toolkits/scalar/SEvaluator__24MetaConstant.h <==
// public abstract class soot.shimple.toolkits.scalar.SEvaluator$MetaConstant

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a4a584ce60f6ce4 soot_jimple_Constant
// @dep_class 430b138846f45212 soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant

// header file dependencies
// @dep_header soot_jimple_Constant

#include "soot/jimple/Constant.h"

#ifndef _JC_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant_H_
#define _JC_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_refs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_refs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_nonrefs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$refs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$refs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$nonrefs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$object	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$object;

typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vmethods	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vmethods;
typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vtable	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vtable;
typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vtype	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vtype;

// Constructors
extern void _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vmethods {
};

// Vtable
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_Constant$vmethods	soot_jimple_Constant;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vmethods	soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant;
};

// Vtype
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vtype {
	_jc_type			type;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$refs {
    _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_refs	soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant;
    _jc_soot_jimple_Constant$sub_refs	soot_jimple_Constant;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_Constant$sub_nonrefs	soot_jimple_Constant;
    _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_nonrefs	soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant;
};

// Object instance structure
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$object {
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vtype	*vtype;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vtype _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$class_object;

#endif	/* _JC_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant_H_ */
